# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/notification.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n opus_protobuf/notification.proto\x12\x0cnotification\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1aopus_protobuf/common.proto2Q\n\x16NotificationController\x12\x37\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x0e.common.Health\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.notification_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NOTIFICATIONCONTROLLER']._serialized_start=107
  _globals['_NOTIFICATIONCONTROLLER']._serialized_end=188
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/user.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18opus_protobuf/user.proto\x12\x04user\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1aopus_protobuf/common.proto\"\xde\x01\n\x04User\x12\x0b\n\x03_id\x18\x01 \x01(\x05\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x11\n\tlast_name\x18\x03 \x01(\t\x12\x12\n\x05\x65mail\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x1c\n\x04type\x18\x05 \x01(\x0b\x32\x0e.user.UserType\x12.\n\x0fprofile_picture\x18\x06 \x01(\x0b\x32\x10.common.DocumentH\x01\x88\x01\x01\x12\x15\n\x08verified\x18\x07 \x01(\x08H\x02\x88\x01\x01\x42\x08\n\x06_emailB\x12\n\x10_profile_pictureB\x0b\n\t_verified\"&\n\x08UserType\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\"S\n\x1e\x43reateTalentOpportunityRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0e\n\x06talent\x18\x02 \x01(\t\x12\x13\n\x0bopportunity\x18\x03 \x01(\t\"i\n\x1f\x43reateTalentOpportunityResponse\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x01 \x01(\x08\x12\x0f\n\x07\x63ompany\x18\x02 \x01(\t\x12\x0e\n\x06talent\x18\x03 \x01(\t\x12\x13\n\x0bopportunity\x18\x04 \x01(\t\"#\n\x13GetShortLinkRequest\x12\x0c\n\x04slug\x18\x01 \x01(\t2\xa1\x04\n\x0eUserController\x12\x37\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x0e.common.Health\"\x00\x12/\n\x07GetUser\x12\x16.google.protobuf.Empty\x1a\n.user.User\"\x00\x12h\n\x17\x43reateTalentOpportunity\x12$.user.CreateTalentOpportunityRequest\x1a%.user.CreateTalentOpportunityResponse\"\x00\x12\x39\n\x11UploadCompanyLogo\x12\x10.common.Document\x1a\x10.common.Response\"\x00\x12\x42\n\x1aUploadCulturalAlertPicture\x12\x10.common.Document\x1a\x10.common.Response\"\x00\x12?\n\x17UploadCulturalAlertDeck\x12\x10.common.Document\x1a\x10.common.Response\"\x00\x12<\n\x14UploadVideoTreatment\x12\x10.common.Document\x1a\x10.common.Response\"\x00\x12=\n\x0cGetShortLink\x12\x19.user.GetShortLinkRequest\x1a\x10.common.Response\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_USER']._serialized_start=92
  _globals['_USER']._serialized_end=314
  _globals['_USERTYPE']._serialized_start=316
  _globals['_USERTYPE']._serialized_end=354
  _globals['_CREATETALENTOPPORTUNITYREQUEST']._serialized_start=356
  _globals['_CREATETALENTOPPORTUNITYREQUEST']._serialized_end=439
  _globals['_CREATETALENTOPPORTUNITYRESPONSE']._serialized_start=441
  _globals['_CREATETALENTOPPORTUNITYRESPONSE']._serialized_end=546
  _globals['_GETSHORTLINKREQUEST']._serialized_start=548
  _globals['_GETSHORTLINKREQUEST']._serialized_end=583
  _globals['_USERCONTROLLER']._serialized_start=586
  _globals['_USERCONTROLLER']._serialized_end=1131
# @@protoc_insertion_point(module_scope)



from google.protobuf import empty_pb2 as _empty_pb2
from opus_protobuf import common_pb2 as _common_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor



from google.protobuf import empty_pb2 as _empty_pb2
from opus_protobuf import common_pb2 as _common_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Post(_message.Message):
    __slots__ = ("id", "approved")
    ID_FIELD_NUMBER: _ClassVar[int]
    APPROVED_FIELD_NUMBER: _ClassVar[int]
    id: str
    approved: bool
    def __init__(self, id: _Optional[str] = ..., approved: bool = ...) -> None: ...

class Posts(_message.Message):
    __slots__ = ("posts",)
    POSTS_FIELD_NUMBER: _ClassVar[int]
    posts: _containers.RepeatedCompositeFieldContainer[Post]
    def __init__(self, posts: _Optional[_Iterable[_Union[Post, _Mapping]]] = ...) -> None: ...

class UserReport(_message.Message):
    __slots__ = ("user", "socialNetwork", "score")
    USER_FIELD_NUMBER: _ClassVar[int]
    SOCIALNETWORK_FIELD_NUMBER: _ClassVar[int]
    SCORE_FIELD_NUMBER: _ClassVar[int]
    user: str
    socialNetwork: str
    score: str
    def __init__(self, user: _Optional[str] = ..., socialNetwork: _Optional[str] = ..., score: _Optional[str] = ...) -> None: ...

class PostReport(_message.Message):
    __slots__ = ("report_likes", "report_comment", "positive_comment", "negative_comment")
    REPORT_LIKES_FIELD_NUMBER: _ClassVar[int]
    REPORT_COMMENT_FIELD_NUMBER: _ClassVar[int]
    POSITIVE_COMMENT_FIELD_NUMBER: _ClassVar[int]
    NEGATIVE_COMMENT_FIELD_NUMBER: _ClassVar[int]
    report_likes: int
    report_comment: int
    positive_comment: int
    negative_comment: int
    def __init__(self, report_likes: _Optional[int] = ..., report_comment: _Optional[int] = ..., positive_comment: _Optional[int] = ..., negative_comment: _Optional[int] = ...) -> None: ...

class ResponseRight(_message.Message):
    __slots__ = ("message",)
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    message: str
    def __init__(self, message: _Optional[str] = ...) -> None: ...

class Industries(_message.Message):
    __slots__ = ("industry",)
    INDUSTRY_FIELD_NUMBER: _ClassVar[int]
    industry: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, industry: _Optional[_Iterable[str]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import authentication_pb2 as opus__protobuf_dot_authentication__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2
from opus_protobuf import user_pb2 as opus__protobuf_dot_user__pb2


class AuthenticationControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HealthCheck = channel.unary_unary(
                '/authentication.AuthenticationController/HealthCheck',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Health.FromString,
                )
        self.Login = channel.unary_unary(
                '/authentication.AuthenticationController/Login',
                request_serializer=opus__protobuf_dot_authentication__pb2.LoginRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
                )
        self.Signup = channel.unary_unary(
                '/authentication.AuthenticationController/Signup',
                request_serializer=opus__protobuf_dot_authentication__pb2.SignupRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
                )
        self.GetUserData = channel.unary_unary(
                '/authentication.AuthenticationController/GetUserData',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_user__pb2.User.FromString,
                )
        self.SignupGoogle = channel.unary_unary(
                '/authentication.AuthenticationController/SignupGoogle',
                request_serializer=opus__protobuf_dot_authentication__pb2.SignupGoogleRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
                )
        self.SignupApple = channel.unary_unary(
                '/authentication.AuthenticationController/SignupApple',
                request_serializer=opus__protobuf_dot_authentication__pb2.SignupAppleRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
                )
        self.UploadProfilePicture = channel.unary_unary(
                '/authentication.AuthenticationController/UploadProfilePicture',
                request_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadProfilePictureUrl = channel.unary_unary(
                '/authentication.AuthenticationController/UploadProfilePictureUrl',
                request_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.TalentProfileCreateCSV = channel.unary_unary(
                '/authentication.AuthenticationController/TalentProfileCreateCSV',
                request_serializer=opus__protobuf_dot_authentication__pb2.TalentProfileCreateCsvRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                )
        self.RefreshToken = channel.unary_unary(
                '/authentication.AuthenticationController/RefreshToken',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
                )


class AuthenticationControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Login(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Signup(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserData(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignupGoogle(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SignupApple(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadProfilePicture(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadProfilePictureUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TalentProfileCreateCSV(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RefreshToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthenticationControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Health.SerializeToString,
            ),
            'Login': grpc.unary_unary_rpc_method_handler(
                    servicer.Login,
                    request_deserializer=opus__protobuf_dot_authentication__pb2.LoginRequest.FromString,
                    response_serializer=opus__protobuf_dot_authentication__pb2.JWTResponse.SerializeToString,
            ),
            'Signup': grpc.unary_unary_rpc_method_handler(
                    servicer.Signup,
                    request_deserializer=opus__protobuf_dot_authentication__pb2.SignupRequest.FromString,
                    response_serializer=opus__protobuf_dot_authentication__pb2.JWTResponse.SerializeToString,
            ),
            'GetUserData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserData,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_user__pb2.User.SerializeToString,
            ),
            'SignupGoogle': grpc.unary_unary_rpc_method_handler(
                    servicer.SignupGoogle,
                    request_deserializer=opus__protobuf_dot_authentication__pb2.SignupGoogleRequest.FromString,
                    response_serializer=opus__protobuf_dot_authentication__pb2.JWTResponse.SerializeToString,
            ),
            'SignupApple': grpc.unary_unary_rpc_method_handler(
                    servicer.SignupApple,
                    request_deserializer=opus__protobuf_dot_authentication__pb2.SignupAppleRequest.FromString,
                    response_serializer=opus__protobuf_dot_authentication__pb2.JWTResponse.SerializeToString,
            ),
            'UploadProfilePicture': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadProfilePicture,
                    request_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadProfilePictureUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadProfilePictureUrl,
                    request_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'TalentProfileCreateCSV': grpc.unary_unary_rpc_method_handler(
                    servicer.TalentProfileCreateCSV,
                    request_deserializer=opus__protobuf_dot_authentication__pb2.TalentProfileCreateCsvRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
            ),
            'RefreshToken': grpc.unary_unary_rpc_method_handler(
                    servicer.RefreshToken,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_authentication__pb2.JWTResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'authentication.AuthenticationController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AuthenticationController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/HealthCheck',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_common__pb2.Health.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Login(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/Login',
            opus__protobuf_dot_authentication__pb2.LoginRequest.SerializeToString,
            opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Signup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/Signup',
            opus__protobuf_dot_authentication__pb2.SignupRequest.SerializeToString,
            opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/GetUserData',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_user__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignupGoogle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/SignupGoogle',
            opus__protobuf_dot_authentication__pb2.SignupGoogleRequest.SerializeToString,
            opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SignupApple(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/SignupApple',
            opus__protobuf_dot_authentication__pb2.SignupAppleRequest.SerializeToString,
            opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadProfilePicture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/UploadProfilePicture',
            opus__protobuf_dot_common__pb2.Document.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadProfilePictureUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/UploadProfilePictureUrl',
            opus__protobuf_dot_common__pb2.Document.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TalentProfileCreateCSV(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/TalentProfileCreateCSV',
            opus__protobuf_dot_authentication__pb2.TalentProfileCreateCsvRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Document.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RefreshToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/authentication.AuthenticationController/RefreshToken',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_authentication__pb2.JWTResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/score.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19opus_protobuf/score.proto\x12\x08\x61nalyzer\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1aopus_protobuf/common.proto\"$\n\x04Post\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x61pproved\x18\x02 \x01(\x08\"&\n\x05Posts\x12\x1d\n\x05posts\x18\x01 \x03(\x0b\x32\x0e.analyzer.Post\"@\n\nUserReport\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x15\n\rsocialNetwork\x18\x02 \x01(\t\x12\r\n\x05score\x18\x03 \x01(\t\"n\n\nPostReport\x12\x14\n\x0creport_likes\x18\x01 \x01(\x05\x12\x16\n\x0ereport_comment\x18\x02 \x01(\x05\x12\x18\n\x10positive_comment\x18\x03 \x01(\x05\x12\x18\n\x10negative_comment\x18\x04 \x01(\x05\" \n\rResponseRight\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x1e\n\nIndustries\x12\x10\n\x08industry\x18\x01 \x03(\t2\xcd\x03\n\x0fScoreController\x12\x37\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x0e.common.Health\"\x00\x12>\n\x0c\x43reateTalent\x12\x13.common.GetItemByID\x1a\x17.analyzer.ResponseRight\"\x00\x12>\n\x0cUpdateTalent\x12\x13.common.GetItemByID\x1a\x17.analyzer.ResponseRight\"\x00\x12>\n\x0c\x44\x65leteTalent\x12\x13.common.GetItemByID\x1a\x17.analyzer.ResponseRight\"\x00\x12\x42\n\x10\x43reateSocialCard\x12\x13.common.GetItemByID\x1a\x17.analyzer.ResponseRight\"\x00\x12@\n\x0e\x43reateAudience\x12\x13.common.GetItemByID\x1a\x17.analyzer.ResponseRight\"\x00\x12;\n\x0f\x43reateAuthority\x12\x14.analyzer.Industries\x1a\x10.common.Response\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.score_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_POST']._serialized_start=96
  _globals['_POST']._serialized_end=132
  _globals['_POSTS']._serialized_start=134
  _globals['_POSTS']._serialized_end=172
  _globals['_USERREPORT']._serialized_start=174
  _globals['_USERREPORT']._serialized_end=238
  _globals['_POSTREPORT']._serialized_start=240
  _globals['_POSTREPORT']._serialized_end=350
  _globals['_RESPONSERIGHT']._serialized_start=352
  _globals['_RESPONSERIGHT']._serialized_end=384
  _globals['_INDUSTRIES']._serialized_start=386
  _globals['_INDUSTRIES']._serialized_end=416
  _globals['_SCORECONTROLLER']._serialized_start=419
  _globals['_SCORECONTROLLER']._serialized_end=880
# @@protoc_insertion_point(module_scope)



from google.protobuf import empty_pb2 as _empty_pb2
from opus_protobuf import common_pb2 as _common_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class User(_message.Message):
    __slots__ = ("_id", "first_name", "last_name", "email", "type", "profile_picture", "verified")
    _ID_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    PROFILE_PICTURE_FIELD_NUMBER: _ClassVar[int]
    VERIFIED_FIELD_NUMBER: _ClassVar[int]
    _id: int
    first_name: str
    last_name: str
    email: str
    type: UserType
    profile_picture: _common_pb2.Document
    verified: bool
    def __init__(self, _id: _Optional[int] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ..., email: _Optional[str] = ..., type: _Optional[_Union[UserType, _Mapping]] = ..., profile_picture: _Optional[_Union[_common_pb2.Document, _Mapping]] = ..., verified: bool = ...) -> None: ...

class UserType(_message.Message):
    __slots__ = ("_id", "label")
    _ID_FIELD_NUMBER: _ClassVar[int]
    LABEL_FIELD_NUMBER: _ClassVar[int]
    _id: str
    label: str
    def __init__(self, _id: _Optional[str] = ..., label: _Optional[str] = ...) -> None: ...

class CreateTalentOpportunityRequest(_message.Message):
    __slots__ = ("user", "talent", "opportunity")
    USER_FIELD_NUMBER: _ClassVar[int]
    TALENT_FIELD_NUMBER: _ClassVar[int]
    OPPORTUNITY_FIELD_NUMBER: _ClassVar[int]
    user: str
    talent: str
    opportunity: str
    def __init__(self, user: _Optional[str] = ..., talent: _Optional[str] = ..., opportunity: _Optional[str] = ...) -> None: ...

class CreateTalentOpportunityResponse(_message.Message):
    __slots__ = ("accepted", "company", "talent", "opportunity")
    ACCEPTED_FIELD_NUMBER: _ClassVar[int]
    COMPANY_FIELD_NUMBER: _ClassVar[int]
    TALENT_FIELD_NUMBER: _ClassVar[int]
    OPPORTUNITY_FIELD_NUMBER: _ClassVar[int]
    accepted: bool
    company: str
    talent: str
    opportunity: str
    def __init__(self, accepted: bool = ..., company: _Optional[str] = ..., talent: _Optional[str] = ..., opportunity: _Optional[str] = ...) -> None: ...

class GetShortLinkRequest(_message.Message):
    __slots__ = ("slug",)
    SLUG_FIELD_NUMBER: _ClassVar[int]
    slug: str
    def __init__(self, slug: _Optional[str] = ...) -> None: ...



from google.protobuf import empty_pb2 as _empty_pb2
from opus_protobuf import user_pb2 as _user_pb2
from opus_protobuf import common_pb2 as _common_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LoginRequest(_message.Message):
    __slots__ = ("email", "password")
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    email: str
    password: str
    def __init__(self, email: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class SignupRequest(_message.Message):
    __slots__ = ("email", "password", "first_name", "last_name")
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    FIRST_NAME_FIELD_NUMBER: _ClassVar[int]
    LAST_NAME_FIELD_NUMBER: _ClassVar[int]
    email: str
    password: str
    first_name: str
    last_name: str
    def __init__(self, email: _Optional[str] = ..., password: _Optional[str] = ..., first_name: _Optional[str] = ..., last_name: _Optional[str] = ...) -> None: ...

class JWTResponse(_message.Message):
    __slots__ = ("_id", "type", "tenants", "verified")
    _ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    TENANTS_FIELD_NUMBER: _ClassVar[int]
    VERIFIED_FIELD_NUMBER: _ClassVar[int]
    _id: str
    type: _user_pb2.UserType
    tenants: _containers.RepeatedScalarFieldContainer[str]
    verified: bool
    def __init__(self, _id: _Optional[str] = ..., type: _Optional[_Union[_user_pb2.UserType, _Mapping]] = ..., tenants: _Optional[_Iterable[str]] = ..., verified: bool = ...) -> None: ...

class SignupGoogleRequest(_message.Message):
    __slots__ = ("token", "type")
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    token: str
    type: str
    def __init__(self, token: _Optional[str] = ..., type: _Optional[str] = ...) -> None: ...

class SignupAppleRequest(_message.Message):
    __slots__ = ("token", "type")
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    token: str
    type: str
    def __init__(self, token: _Optional[str] = ..., type: _Optional[str] = ...) -> None: ...

class TalentProfileCreateCsvRequest(_message.Message):
    __slots__ = ("email", "birthday", "tenant", "industry", "industry_segment", "country")
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    BIRTHDAY_FIELD_NUMBER: _ClassVar[int]
    TENANT_FIELD_NUMBER: _ClassVar[int]
    INDUSTRY_FIELD_NUMBER: _ClassVar[int]
    INDUSTRY_SEGMENT_FIELD_NUMBER: _ClassVar[int]
    COUNTRY_FIELD_NUMBER: _ClassVar[int]
    email: str
    birthday: str
    tenant: _containers.RepeatedScalarFieldContainer[str]
    industry: str
    industry_segment: str
    country: str
    def __init__(self, email: _Optional[str] = ..., birthday: _Optional[str] = ..., tenant: _Optional[_Iterable[str]] = ..., industry: _Optional[str] = ..., industry_segment: _Optional[str] = ..., country: _Optional[str] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2
from opus_protobuf import score_pb2 as opus__protobuf_dot_score__pb2


class ScoreControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HealthCheck = channel.unary_unary(
                '/analyzer.ScoreController/HealthCheck',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Health.FromString,
                )
        self.CreateTalent = channel.unary_unary(
                '/analyzer.ScoreController/CreateTalent',
                request_serializer=opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
                response_deserializer=opus__protobuf_dot_score__pb2.ResponseRight.FromString,
                )
        self.UpdateTalent = channel.unary_unary(
                '/analyzer.ScoreController/UpdateTalent',
                request_serializer=opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
                response_deserializer=opus__protobuf_dot_score__pb2.ResponseRight.FromString,
                )
        self.DeleteTalent = channel.unary_unary(
                '/analyzer.ScoreController/DeleteTalent',
                request_serializer=opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
                response_deserializer=opus__protobuf_dot_score__pb2.ResponseRight.FromString,
                )
        self.CreateSocialCard = channel.unary_unary(
                '/analyzer.ScoreController/CreateSocialCard',
                request_serializer=opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
                response_deserializer=opus__protobuf_dot_score__pb2.ResponseRight.FromString,
                )
        self.CreateAudience = channel.unary_unary(
                '/analyzer.ScoreController/CreateAudience',
                request_serializer=opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
                response_deserializer=opus__protobuf_dot_score__pb2.ResponseRight.FromString,
                )
        self.CreateAuthority = channel.unary_unary(
                '/analyzer.ScoreController/CreateAuthority',
                request_serializer=opus__protobuf_dot_score__pb2.Industries.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )


class ScoreControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTalent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTalent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTalent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSocialCard(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAudience(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateAuthority(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ScoreControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Health.SerializeToString,
            ),
            'CreateTalent': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTalent,
                    request_deserializer=opus__protobuf_dot_common__pb2.GetItemByID.FromString,
                    response_serializer=opus__protobuf_dot_score__pb2.ResponseRight.SerializeToString,
            ),
            'UpdateTalent': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTalent,
                    request_deserializer=opus__protobuf_dot_common__pb2.GetItemByID.FromString,
                    response_serializer=opus__protobuf_dot_score__pb2.ResponseRight.SerializeToString,
            ),
            'DeleteTalent': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteTalent,
                    request_deserializer=opus__protobuf_dot_common__pb2.GetItemByID.FromString,
                    response_serializer=opus__protobuf_dot_score__pb2.ResponseRight.SerializeToString,
            ),
            'CreateSocialCard': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSocialCard,
                    request_deserializer=opus__protobuf_dot_common__pb2.GetItemByID.FromString,
                    response_serializer=opus__protobuf_dot_score__pb2.ResponseRight.SerializeToString,
            ),
            'CreateAudience': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAudience,
                    request_deserializer=opus__protobuf_dot_common__pb2.GetItemByID.FromString,
                    response_serializer=opus__protobuf_dot_score__pb2.ResponseRight.SerializeToString,
            ),
            'CreateAuthority': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateAuthority,
                    request_deserializer=opus__protobuf_dot_score__pb2.Industries.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'analyzer.ScoreController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ScoreController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/analyzer.ScoreController/HealthCheck',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_common__pb2.Health.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTalent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/analyzer.ScoreController/CreateTalent',
            opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
            opus__protobuf_dot_score__pb2.ResponseRight.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTalent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/analyzer.ScoreController/UpdateTalent',
            opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
            opus__protobuf_dot_score__pb2.ResponseRight.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteTalent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/analyzer.ScoreController/DeleteTalent',
            opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
            opus__protobuf_dot_score__pb2.ResponseRight.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSocialCard(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/analyzer.ScoreController/CreateSocialCard',
            opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
            opus__protobuf_dot_score__pb2.ResponseRight.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAudience(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/analyzer.ScoreController/CreateAudience',
            opus__protobuf_dot_common__pb2.GetItemByID.SerializeToString,
            opus__protobuf_dot_score__pb2.ResponseRight.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateAuthority(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/analyzer.ScoreController/CreateAuthority',
            opus__protobuf_dot_score__pb2.Industries.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Document(_message.Message):
    __slots__ = ("url", "type", "_id")
    URL_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    _ID_FIELD_NUMBER: _ClassVar[int]
    url: str
    type: str
    _id: str
    def __init__(self, url: _Optional[str] = ..., type: _Optional[str] = ..., _id: _Optional[str] = ...) -> None: ...

class GetItemByID(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class Health(_message.Message):
    __slots__ = ("health",)
    HEALTH_FIELD_NUMBER: _ClassVar[int]
    health: bool
    def __init__(self, health: bool = ...) -> None: ...

class Response(_message.Message):
    __slots__ = ("res",)
    RES_FIELD_NUMBER: _ClassVar[int]
    res: bool
    def __init__(self, res: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/authentication.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import user_pb2 as opus__protobuf_dot_user__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"opus_protobuf/authentication.proto\x12\x0e\x61uthentication\x1a\x1bgoogle/protobuf/empty.proto\x1a\x18opus_protobuf/user.proto\x1a\x1aopus_protobuf/common.proto\"/\n\x0cLoginRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"W\n\rSignupRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x12\n\nfirst_name\x18\x03 \x01(\t\x12\x11\n\tlast_name\x18\x04 \x01(\t\"m\n\x0bJWTResponse\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x1c\n\x04type\x18\x02 \x01(\x0b\x32\x0e.user.UserType\x12\x0f\n\x07tenants\x18\x03 \x03(\t\x12\x15\n\x08verified\x18\x04 \x01(\x08H\x00\x88\x01\x01\x42\x0b\n\t_verified\"2\n\x13SignupGoogleRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"1\n\x12SignupAppleRequest\x12\r\n\x05token\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\"\x8d\x01\n\x1dTalentProfileCreateCsvRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08\x62irthday\x18\x02 \x01(\t\x12\x0e\n\x06tenant\x18\x03 \x03(\t\x12\x10\n\x08industry\x18\x04 \x01(\t\x12\x18\n\x10industry_segment\x18\x05 \x01(\t\x12\x0f\n\x07\x63ountry\x18\x06 \x01(\t2\xdf\x05\n\x18\x41uthenticationController\x12\x37\n\x0bHealthCheck\x12\x16.google.protobuf.Empty\x1a\x0e.common.Health\"\x00\x12\x44\n\x05Login\x12\x1c.authentication.LoginRequest\x1a\x1b.authentication.JWTResponse\"\x00\x12\x46\n\x06Signup\x12\x1d.authentication.SignupRequest\x1a\x1b.authentication.JWTResponse\"\x00\x12\x33\n\x0bGetUserData\x12\x16.google.protobuf.Empty\x1a\n.user.User\"\x00\x12R\n\x0cSignupGoogle\x12#.authentication.SignupGoogleRequest\x1a\x1b.authentication.JWTResponse\"\x00\x12P\n\x0bSignupApple\x12\".authentication.SignupAppleRequest\x1a\x1b.authentication.JWTResponse\"\x00\x12<\n\x14UploadProfilePicture\x12\x10.common.Document\x1a\x10.common.Response\"\x00\x12?\n\x17UploadProfilePictureUrl\x12\x10.common.Document\x1a\x10.common.Response\"\x00\x12[\n\x16TalentProfileCreateCSV\x12-.authentication.TalentProfileCreateCsvRequest\x1a\x10.common.Document\"\x00\x12\x45\n\x0cRefreshToken\x12\x16.google.protobuf.Empty\x1a\x1b.authentication.JWTResponse\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.authentication_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LOGINREQUEST']._serialized_start=137
  _globals['_LOGINREQUEST']._serialized_end=184
  _globals['_SIGNUPREQUEST']._serialized_start=186
  _globals['_SIGNUPREQUEST']._serialized_end=273
  _globals['_JWTRESPONSE']._serialized_start=275
  _globals['_JWTRESPONSE']._serialized_end=384
  _globals['_SIGNUPGOOGLEREQUEST']._serialized_start=386
  _globals['_SIGNUPGOOGLEREQUEST']._serialized_end=436
  _globals['_SIGNUPAPPLEREQUEST']._serialized_start=438
  _globals['_SIGNUPAPPLEREQUEST']._serialized_end=487
  _globals['_TALENTPROFILECREATECSVREQUEST']._serialized_start=490
  _globals['_TALENTPROFILECREATECSVREQUEST']._serialized_end=631
  _globals['_AUTHENTICATIONCONTROLLER']._serialized_start=634
  _globals['_AUTHENTICATIONCONTROLLER']._serialized_end=1369
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opus_protobuf/common.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aopus_protobuf/common.proto\x12\x06\x63ommon\"?\n\x08\x44ocument\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x10\n\x03_id\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x06\n\x04X_id\"\x19\n\x0bGetItemByID\x12\n\n\x02id\x18\x01 \x01(\t\"\x18\n\x06Health\x12\x0e\n\x06health\x18\x01 \x01(\x08\"\x17\n\x08Response\x12\x0b\n\x03res\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'opus_protobuf.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DOCUMENT']._serialized_start=38
  _globals['_DOCUMENT']._serialized_end=101
  _globals['_GETITEMBYID']._serialized_start=103
  _globals['_GETITEMBYID']._serialized_end=128
  _globals['_HEALTH']._serialized_start=130
  _globals['_HEALTH']._serialized_end=154
  _globals['_RESPONSE']._serialized_start=156
  _globals['_RESPONSE']._serialized_end=179
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from opus_protobuf import common_pb2 as opus__protobuf_dot_common__pb2
from opus_protobuf import user_pb2 as opus__protobuf_dot_user__pb2


class UserControllerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.HealthCheck = channel.unary_unary(
                '/user.UserController/HealthCheck',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Health.FromString,
                )
        self.GetUser = channel.unary_unary(
                '/user.UserController/GetUser',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=opus__protobuf_dot_user__pb2.User.FromString,
                )
        self.CreateTalentOpportunity = channel.unary_unary(
                '/user.UserController/CreateTalentOpportunity',
                request_serializer=opus__protobuf_dot_user__pb2.CreateTalentOpportunityRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_user__pb2.CreateTalentOpportunityResponse.FromString,
                )
        self.UploadCompanyLogo = channel.unary_unary(
                '/user.UserController/UploadCompanyLogo',
                request_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadCulturalAlertPicture = channel.unary_unary(
                '/user.UserController/UploadCulturalAlertPicture',
                request_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadCulturalAlertDeck = channel.unary_unary(
                '/user.UserController/UploadCulturalAlertDeck',
                request_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.UploadVideoTreatment = channel.unary_unary(
                '/user.UserController/UploadVideoTreatment',
                request_serializer=opus__protobuf_dot_common__pb2.Document.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )
        self.GetShortLink = channel.unary_unary(
                '/user.UserController/GetShortLink',
                request_serializer=opus__protobuf_dot_user__pb2.GetShortLinkRequest.SerializeToString,
                response_deserializer=opus__protobuf_dot_common__pb2.Response.FromString,
                )


class UserControllerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def HealthCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateTalentOpportunity(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadCompanyLogo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadCulturalAlertPicture(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadCulturalAlertDeck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UploadVideoTreatment(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetShortLink(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'HealthCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.HealthCheck,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Health.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=opus__protobuf_dot_user__pb2.User.SerializeToString,
            ),
            'CreateTalentOpportunity': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTalentOpportunity,
                    request_deserializer=opus__protobuf_dot_user__pb2.CreateTalentOpportunityRequest.FromString,
                    response_serializer=opus__protobuf_dot_user__pb2.CreateTalentOpportunityResponse.SerializeToString,
            ),
            'UploadCompanyLogo': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadCompanyLogo,
                    request_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadCulturalAlertPicture': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadCulturalAlertPicture,
                    request_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadCulturalAlertDeck': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadCulturalAlertDeck,
                    request_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'UploadVideoTreatment': grpc.unary_unary_rpc_method_handler(
                    servicer.UploadVideoTreatment,
                    request_deserializer=opus__protobuf_dot_common__pb2.Document.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
            'GetShortLink': grpc.unary_unary_rpc_method_handler(
                    servicer.GetShortLink,
                    request_deserializer=opus__protobuf_dot_user__pb2.GetShortLinkRequest.FromString,
                    response_serializer=opus__protobuf_dot_common__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'user.UserController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserController(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def HealthCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/HealthCheck',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_common__pb2.Health.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/GetUser',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            opus__protobuf_dot_user__pb2.User.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateTalentOpportunity(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/CreateTalentOpportunity',
            opus__protobuf_dot_user__pb2.CreateTalentOpportunityRequest.SerializeToString,
            opus__protobuf_dot_user__pb2.CreateTalentOpportunityResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadCompanyLogo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/UploadCompanyLogo',
            opus__protobuf_dot_common__pb2.Document.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadCulturalAlertPicture(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/UploadCulturalAlertPicture',
            opus__protobuf_dot_common__pb2.Document.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadCulturalAlertDeck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/UploadCulturalAlertDeck',
            opus__protobuf_dot_common__pb2.Document.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UploadVideoTreatment(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/UploadVideoTreatment',
            opus__protobuf_dot_common__pb2.Document.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetShortLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/user.UserController/GetShortLink',
            opus__protobuf_dot_user__pb2.GetShortLinkRequest.SerializeToString,
            opus__protobuf_dot_common__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
